@@ -3,7 +3,7 @@ package chezmoi
 import (
 	"log/slog"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
+	"github.com/twpayne/chezmoi/internal/chezmoilog"
 )
 
 // A DebugPersistentState logs calls to a PersistentState.
