@@ -12,7 +12,7 @@ import (
 
 	"github.com/spf13/cobra"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
 )
 
 var (
@@ -164,12 +164,10 @@ func parseMackupApplication(data []byte) (mackupApplicationConfig, error) {
 		if text == "" {
 			continue
 		}
-		//nolint:gocritic
 		switch section {
 		case "application":
 			if m := mackupKeyValueRx.FindStringSubmatch(text); m != nil {
-				switch m[1] {
-				case "name":
+				if m[1] == "name" {
 					config.Application.Name = m[2]
 				}
 			}
