@@ -8,7 +8,7 @@ import (
 	"slices"
 	"strings"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
+	"github.com/twpayne/chezmoi/internal/chezmoilog"
 )
 
 type secretConfig struct {
